@@ -1,7 +1,7 @@
 package IOD;
 
-our $DATE = '2014-08-18'; # DATE
-our $VERSION = '0.9.5'; # VERSION
+our $DATE = '2014-08-28'; # DATE
+our $VERSION = '0.9.6'; # VERSION
 
 1;
 # ABSTRACT: IOD (INI On Drugs) file format specification
@@ -18,7 +18,7 @@ IOD - IOD (INI On Drugs) file format specification
 
 =head1 VERSION
 
-This document describes version 0.9.5 of IOD (from Perl distribution IOD), released on 2014-08-18.
+This document describes version 0.9.6 of IOD (from Perl distribution IOD), released on 2014-08-28.
 
 =head1 HOMEPAGE
 
@@ -26,7 +26,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/IOD>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-IOD>.
+Source repository is at L<https://github.com/perlancar/perl-IOD>.
 
 =head1 BUGS
 
@@ -38,11 +38,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
